import { ComponentOptionsMixin } from 'vue';
import { ComputedRef } from 'vue';
import { DefineComponent } from 'vue';
import { ExtractPropTypes } from 'vue';
import { NormalizedScopedSlot } from 'vue/types/vnode';
import { PropType } from 'vue';
import { Ref } from 'vue';

export declare const DataTable: DefineComponent<    {
source: {
type: PropType<DTSource>;
default: string;
};
url: {
type: PropType<string | null>;
default: null;
};
items: {
type: PropType<DTRowItem[]>;
default: () => never[];
};
pagination: {
type: BooleanConstructor;
default: boolean;
};
rowsPerPageCount: {
type: NumberConstructor;
default: number;
};
rowsPerPageOptions: {
type: PropType<number[]>;
default: () => number[];
};
searching: {
type: BooleanConstructor;
default: boolean;
};
orderBy: {
type: PropType<string | null>;
default: null;
};
orderDirection: {
type: PropType<DTOrderDirection>;
default: string;
};
rowSelection: {
type: BooleanConstructor;
default: boolean;
};
actions: {
type: BooleanConstructor;
default: boolean;
};
numbering: {
type: BooleanConstructor;
default: boolean;
};
scrollX: {
type: BooleanConstructor;
default: boolean;
};
fixedColumnsStart: {
type: NumberConstructor;
required: boolean;
default: number;
};
fixedColumnsEnd: {
type: NumberConstructor;
required: boolean;
default: number;
};
rowsClickable: {
type: BooleanConstructor;
default: boolean;
};
}, {
error: Ref<DTError | null>;
search: Ref<string>;
page: Ref<number>;
rowsPerPage: Ref<number>;
order: Ref<DTOrderColumn | null>;
columns: Ref<DTColumn[]>;
tableData: Ref<DTTableData | null>;
selectedRowIndexes: Ref<number[]>;
isSelectedAll: ComputedRef<boolean>;
handleSearchInput: (value: string) => void;
handleRowsPerPageInput: (value: number) => void;
handlePageInput: (value: number) => void;
handleOrderUpdate: (value: DTOrder) => void;
handleSelectAll: () => void;
handleDeselectAll: () => void;
handleSelectRow: (index: number) => void;
handleDeselectRow: (index: number) => void;
handleClickRow: (row: DTRow) => void;
reload: () => Promise<void>;
}, {}, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, {
'update:selected-rows': (value: any) => true;
'click:row': (row: DTRow) => true;
}, string, Readonly<ExtractPropTypes<    {
source: {
type: PropType<DTSource>;
default: string;
};
url: {
type: PropType<string | null>;
default: null;
};
items: {
type: PropType<DTRowItem[]>;
default: () => never[];
};
pagination: {
type: BooleanConstructor;
default: boolean;
};
rowsPerPageCount: {
type: NumberConstructor;
default: number;
};
rowsPerPageOptions: {
type: PropType<number[]>;
default: () => number[];
};
searching: {
type: BooleanConstructor;
default: boolean;
};
orderBy: {
type: PropType<string | null>;
default: null;
};
orderDirection: {
type: PropType<DTOrderDirection>;
default: string;
};
rowSelection: {
type: BooleanConstructor;
default: boolean;
};
actions: {
type: BooleanConstructor;
default: boolean;
};
numbering: {
type: BooleanConstructor;
default: boolean;
};
scrollX: {
type: BooleanConstructor;
default: boolean;
};
fixedColumnsStart: {
type: NumberConstructor;
required: boolean;
default: number;
};
fixedColumnsEnd: {
type: NumberConstructor;
required: boolean;
default: number;
};
rowsClickable: {
type: BooleanConstructor;
default: boolean;
};
}>>, {
source: DTSource;
url: string | null;
items: DTRowItem[];
pagination: boolean;
rowsPerPageCount: number;
rowsPerPageOptions: number[];
searching: boolean;
orderBy: string | null;
orderDirection: DTOrderDirection;
rowSelection: boolean;
actions: boolean;
numbering: boolean;
scrollX: boolean;
fixedColumnsStart: number;
fixedColumnsEnd: number;
rowsClickable: boolean;
}>;

export declare const DataTableColumn: DefineComponent<    {
field: {
type: StringConstructor;
required: true;
};
title: {
type: StringConstructor;
required: false;
default: null;
};
orderable: {
type: BooleanConstructor;
default: boolean;
};
searchable: {
type: BooleanConstructor;
default: boolean;
};
width: {
type: StringConstructor;
required: false;
default: undefined;
};
textAlign: {
type: PropType<DTTextAlign>;
default: undefined;
};
}, {}, {
rowPlug: DTRow;
}, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, {}, string, Readonly<ExtractPropTypes<    {
field: {
type: StringConstructor;
required: true;
};
title: {
type: StringConstructor;
required: false;
default: null;
};
orderable: {
type: BooleanConstructor;
default: boolean;
};
searchable: {
type: BooleanConstructor;
default: boolean;
};
width: {
type: StringConstructor;
required: false;
default: undefined;
};
textAlign: {
type: PropType<DTTextAlign>;
default: undefined;
};
}>>, {
title: string;
orderable: boolean;
searchable: boolean;
width: string;
textAlign: DTTextAlign;
}>;

export declare type DTColumn = {
    readonly index: number;
    readonly params: DTColumnParams;
    readonly slots: DTColumnSlots;
    readonly appearance: DTColumnAppearance;
};

declare type DTColumnAppearance = {
    readonly styleObject: Record<string, string | number>;
    readonly classObject: Record<string, boolean>;
};

declare type DTColumnParams = {
    readonly field: string;
    readonly title: string | null;
    readonly orderable: boolean;
    readonly searchable: boolean;
};

export declare type DTColumnProps = {
    readonly field: string;
    readonly title: string;
    readonly orderable: boolean;
    readonly searchable: boolean;
    readonly width: string | undefined;
    readonly textAlign: DTTextAlign | undefined;
};

declare type DTColumnSlots = {
    readonly cell: NormalizedScopedSlot | undefined;
    readonly filter: NormalizedScopedSlot | undefined;
};

/**
 * Error
 */
export declare type DTError = {
    message: string;
    description?: string | null;
};

export declare type DTOrder = DTOrderColumn;

export declare type DTOrderColumn = {
    readonly column: string;
    readonly direction: DTOrderDirection;
};

/**
 * Order
 */
export declare type DTOrderDirection = 'asc' | 'desc';

export declare type DTRow = {
    readonly index: number;
    readonly number: number;
    readonly item: DTRowItem;
};

export declare type DTRowItem = Record<string, DTRowItemValue>;

export declare type DTRowItemValue = string | number | boolean | null;

/**
 * Table data
 */
export declare type DTSource = 'server' | 'client';

export declare type DTTable = typeof DataTable & DTTableProps & {
    reload: () => Promise<void>;
};

export declare type DTTableData = {
    readonly total: number;
    readonly filtered: number;
    readonly rows: DTRow[];
};

export declare type DTTableProps = ExtractPropTypes<typeof tableProps>;

/**
 * Columns
 */
export declare type DTTextAlign = 'center' | 'left' | 'right';

declare const tableProps: {
    source: {
        type: PropType<DTSource>;
        default: string;
    };
    url: {
        type: PropType<string | null>;
        default: null;
    };
    items: {
        type: PropType<DTRowItem[]>;
        default: () => never[];
    };
    pagination: {
        type: BooleanConstructor;
        default: boolean;
    };
    rowsPerPageCount: {
        type: NumberConstructor;
        default: number;
    };
    rowsPerPageOptions: {
        type: PropType<number[]>;
        default: () => number[];
    };
    searching: {
        type: BooleanConstructor;
        default: boolean;
    };
    orderBy: {
        type: PropType<string | null>;
        default: null;
    };
    orderDirection: {
        type: PropType<DTOrderDirection>;
        default: string;
    };
    rowSelection: {
        type: BooleanConstructor;
        default: boolean;
    };
    actions: {
        type: BooleanConstructor;
        default: boolean;
    };
    numbering: {
        type: BooleanConstructor;
        default: boolean;
    };
    scrollX: {
        type: BooleanConstructor;
        default: boolean;
    };
    fixedColumnsStart: {
        type: NumberConstructor;
        required: boolean;
        default: number;
    };
    fixedColumnsEnd: {
        type: NumberConstructor;
        required: boolean;
        default: number;
    };
    rowsClickable: {
        type: BooleanConstructor;
        default: boolean;
    };
};

export { }
